@@ -2,6 +2,6 @@ from spei.client import BaseClient
 from spei.sice import BaseClient as SICEClient
 
 __all__ = [  # noqa: WPS410
-    BaseClient,
-    SICEClient,
+    'BaseClient',
+    'SICEClient',
 ]
